aboutsummaryrefslogtreecommitdiffstats
path: root/include/usrp_uhd/usrp/dboard/manager.hpp
diff options
context:
space:
mode:
authorJosh Blum <josh@joshknows.com>2010-01-26 11:29:14 -0800
committerJosh Blum <josh@joshknows.com>2010-01-26 11:29:14 -0800
commita98e387578a3aceb15e2bcce4a9cc54d78c30dda (patch)
treeb5e34c422c36a16a3f2379698e81af4c00a66ee3 /include/usrp_uhd/usrp/dboard/manager.hpp
parent998aebf83c2796fdfabc2efd804ca14103adcaaf (diff)
downloaduhd-a98e387578a3aceb15e2bcce4a9cc54d78c30dda.tar.gz
uhd-a98e387578a3aceb15e2bcce4a9cc54d78c30dda.tar.bz2
uhd-a98e387578a3aceb15e2bcce4a9cc54d78c30dda.zip
Switched from indexed properties to named properties.
Added some new properties for getting a list of antenna names, pps sources, ref sources...
Diffstat (limited to 'include/usrp_uhd/usrp/dboard/manager.hpp')
-rw-r--r--include/usrp_uhd/usrp/dboard/manager.hpp19
1 files changed, 10 insertions, 9 deletions
diff --git a/include/usrp_uhd/usrp/dboard/manager.hpp b/include/usrp_uhd/usrp/dboard/manager.hpp
index d977fa527..4eaa9f889 100644
--- a/include/usrp_uhd/usrp/dboard/manager.hpp
+++ b/include/usrp_uhd/usrp/dboard/manager.hpp
@@ -5,8 +5,9 @@
#ifndef INCLUDED_USRP_UHD_USRP_DBOARD_MANAGER_HPP
#define INCLUDED_USRP_UHD_USRP_DBOARD_MANAGER_HPP
-#include <vector>
+#include <map>
#include <usrp_uhd/wax.hpp>
+#include <usrp_uhd/props.hpp>
#include <boost/utility.hpp>
#include <boost/shared_ptr.hpp>
#include <usrp_uhd/usrp/dboard/base.hpp>
@@ -32,12 +33,12 @@ public:
*
* \param dboard_id the dboard id (rx or tx)
* \param dboard_ctor the dboard constructor function pointer
* \param num_subdevs the number of subdevs in this dboard
*/
static void register_subdevs(
dboard_id_t dboard_id,
dboard_ctor_t dboard_ctor,
- size_t num_subdevs
+ const prop_names_t &subdev_names
);
public:
@@ -51,16 +52,16 @@ public:
~manager(void);
//interface
- size_t get_num_rx_subdevs(void);
- size_t get_num_tx_subdevs(void);
- wax::obj::sptr get_rx_subdev(size_t subdev_index);
- wax::obj::sptr get_tx_subdev(size_t subdev_index);
+ prop_names_t get_rx_subdev_names(void);
+ prop_names_t get_tx_subdev_names(void);
+ wax::obj::sptr get_rx_subdev(const std::string &subdev_name);
+ wax::obj::sptr get_tx_subdev(const std::string &subdev_name);
private:
//list of rx and tx dboards in this manager
//each dboard here is actually a subdevice
- std::vector<base::sptr> _rx_dboards;
- std::vector<base::sptr> _tx_dboards;
+ std::map<std::string, base::sptr> _rx_dboards;
+ std::map<std::string, base::sptr> _tx_dboards;
};
}}} //namespace
@@ -32,12 +33,12 @@ public:
* \param dboard_id the dboard id (rx or tx)
* \param dboard_ctor the dboard constructor function pointer
- * \param num_subdevs the number of subdevs in this dboard
+ * \param subdev_names the names of the subdevs on this dboard
*/
static void register_subdevs(